@@ -16,6 +16,12 @@ class MetaDataHolder(object):
     def __init__(self, meta=None, **kwds):
         """ Adds MetaData to the class.
         with defaults set to self.zInfo['metadata'].
+
+        Parameters
+        ----------
+
+        Returns
+        -------
         """
         if meta is None:
             meta = metadata.MetaData()
@@ -25,12 +31,36 @@ class MetaDataHolder(object):
     def getMeta(self):
         """ Returns the current MetaData container of this object. 
         Cannot become a python property because setMeta is in Attributable
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+
         """
         return self._meta
 
     def hasMeta(self):
         """ whether the metadata holder is present.
         During initialization subclass of MetaDataHolder may need to know if the metadata holder has been put in place with is method.
-        """
 
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
         return hasattr(self, '_meta')
+
+    def setMeta(self, meta):
+        """
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
+        self._meta = meta
