@@ -10,7 +10,11 @@ class Typed(object):
 
     def __init__(self, typ_=None, **kwds):
         """ Has a type.
+        Parameters
+        ----------
 
+        Returns
+        -------
         """
 
         self.setType(typ_)
@@ -20,22 +24,41 @@ class Typed(object):
     @property
     def type(self):
         """ for property getter
+        Parameters
+        ----------
+
+        Returns
+        -------
         """
         return self.getType()
 
     @type.setter
     def type(self, typ_):
         """ Must be in ParameterTypes.
+        Parameters
+        ----------
+        Returns
+        -------
         """
         self.setType(typ_)
 
     def getType(self):
         """ Returns the actual type that is allowed for the value
-        of this Parameter."""
+        of this Parameter.
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
         return self._type
 
     def setType(self, typ_):
         """ Replaces the current type of this parameter.
+        Parameters
+        ----------
 
+        Returns
+        -------
         """
         self._type = typ_
