@@ -26,16 +26,6 @@ logger = logging.getLogger(__name__)
 #logger.debug('level %d' % (logger.getEffectiveLevel()))
 
 
-common_header = {
-    'Accept': 'application/json',
-    'Accept-Charset': 'utf-8',
-    'Accept-Encoding': 'identity',
-    'Cache-Control': 'no-cache',
-    'Connection': 'keep-alive',
-    "Content-type": 'application/json'
-}
-
-
 pcc = getConfig()
 defaulturl = 'http://' + pcc['node']['host'] + \
     ':' + str(pcc['node']['port']) + pcc['baseurl']
@@ -155,7 +145,8 @@ def read_from_server(urn, poolurl, contents='product'):
     # print("GET REQUEST API: " + api)
     res = requests.get(api, auth=auth)
     result = deserialize(res.text)
-    return result['result'], result['msg']
+    code = result['code'] if 'code' in result else 200
+    return code, result['result'], result['msg']
 
 
 def put_on_server(urn, poolurl, contents='pool'):
