@@ -10,18 +10,26 @@ from fdi.dataset.serializable import serialize
 from fdi.dataset.deserialize import deserialize
 from fdi.dataset.product import Product
 from fdi.pal.poolmanager import PoolManager
+from fdi.pal.productstorage import ProductStorage
 from fdi.utils.common import lls, trbk, fullname
 from fdi.utils.fetch import fetch
-#from fdi.pns import httppool_server as HS
-
+from fdi.httppool.route import httppool_server
+from fdi.pns.jsonio import auth_headers
 
+import pytest
 import filelock
 import sys
 from urllib.request import pathname2url
+from urllib.error import URLError
+
+from flask import current_app
 from requests.auth import HTTPBasicAuth
-import requests
+from requests.models import Response as rmResponse  # mock server
+from flask.wrappers import Response as fwResponse  # live server
+# import requests
 import random
 import os
+import requests
 import pytest
 from pprint import pprint
 
@@ -65,7 +73,7 @@ if 0:
         return smtplib.SMTP("smtp.gmail.com", 587, timeout=5)
 
 
-# last timestamp/lastUpdate
+# last time/lastUpdate
 lupd = 0
 
 
@@ -85,13 +93,19 @@ if 0:
     sys.exit()
 
 
+@pytest.fixture(scope="module")
+def project_app(pc):
+    from httppool_app import create_app
+    return create_app(config_object=pc, logger=logger)
+
+
 def issane(o):
     """ basic check on return """
     global lupd
     assert o is not None, "Server is having trouble"
     assert 'error' not in o, o['error']
-    assert o['timestamp'] > lupd
-    lupd = o['timestamp']
+    assert o['time'] > lupd
+    lupd = o['time']
 
 
 def check0result(result, msg):
@@ -100,11 +114,11 @@ def check0result(result, msg):
     assert msg == '' or not isinstance(msg, (str, bytes)), msg
 
 
-def est_getpnspoolconfig(pc, setup):
+def est_getpnspoolconfig(pc, server):
     ''' gets and compares pnspoolconfig remote and local
     '''
     logger.info('get pnsconfig')
-    aburl, headers = setup
+    aburl, headers = server
     o = getJsonObj(aburl + '/'+'pnsconfig')
     issane(o)
     r = o['result']
@@ -115,16 +129,179 @@ def est_getpnspoolconfig(pc, setup):
 
 # TEST HTTPPOOL  API
 
+def getPayload(aResponse):
+    """ deserializes, if content_type is json, data or tex of responses from wither the live server or the mock one.
+    """
 
-def check_response(o, failed_case=False):
+    x = aResponse.data if issubclass(
+        aResponse.__class__, fwResponse) else aResponse.text
+    if aResponse.headers['Content-Type'] == 'application/json':
+        return deserialize(x)
+    else:
+        return x
+
+
+def check_response(o, failed_case=False, excluded=None):
+    """ Generic checking.
+
+    :o: deserialized response data or text.
+    :failed_case: True if expecing Fail result; False (default) if Success result; None if to ignore `result` being Fails or not.
+    :excluded: a list of string, any of which appears in `result` is to exclude this call from being checked "FAILED".
+    """
     global lupd
+    if excluded is None:
+        excluded = []
     assert o is not None, "Server is having trouble"
+    someone = any(x in o for x in excluded)
     if not failed_case:
-        assert 'FAILED' != o['result'], o['result']
-        assert o['timestamp'] > lupd
-        lupd = o['timestamp']
+        assert 'result' in o or \
+            'Bad string to decode as JSON' not in o \
+            or someone, o
+        if not someone:
+            # properly formated
+            if failed_case is not None:
+                assert 'FAILED' != o['result'], o['result']
+                assert o['code'] == 200, str(o)
+                assert o['time'] > lupd
+                lupd = o['time']
+            return True
     else:
         assert 'FAILED' == o['result'], o['result']
+        assert o['code'] >= 400, str(o)
+        return True
+    return False  # not properly formated
+
+
+def test_clear_local_server(local_pools_dir):
+    clrpool = 'test_clear'
+    ppath = os.path.join(local_pools_dir, clrpool)
+    if not os.path.exists(ppath):
+        os.makedirs(ppath)
+    assert os.path.exists(ppath)
+    with open(ppath+'/foo', 'w') as f:
+        f.write('k')
+    clear_server_local_pools_dir(clrpool, local_pools_dir)
+    assert not os.path.exists(ppath)
+
+
+def make_pools(name, aburl, clnt, auth, n=1):
+    """ generate n pools """
+
+    lst = []
+    for i in range(n):
+        poolid = name + str(i)
+        pool = PoolManager.getPool(poolid, aburl + '/'+poolid)
+        lst.append(pool)
+        data = serialize(Product('lone prod in '+poolid))
+        url = aburl + '/' + poolid + '/' + prodt + '/0'
+        x = clnt.post(url, auth=auth, data=data)
+    return lst[0] if n == 1 else lst
+
+
+def test_wipe_all_pools_on_server(server, local_pools_dir, client, userpass):
+    aburl, headers = server
+    post_poolid = test_poolid
+    auth = HTTPBasicAuth(*userpass)
+    # ======== wipe all pools =====
+    logger.info('Wipe all pools on the server')
+
+    # make some pools
+    n = 5
+    lst = make_pools(post_poolid, aburl, client, auth, n)
+    # make an unregistered pool by copying an existing pool
+    p = os.path.join(local_pools_dir, lst[0].getId())
+    os.system('cp -rf %s %s_copy' % (p, p))
+    assert os.path.exists(p+'_copy')
+
+    assert len(get_files_in_local_dir('', local_pools_dir)) >= n+1
+
+    # wipe all pools
+    url = aburl + '/' + 'wipe_all_pools'
+    x = client.put(url, auth=auth)
+    o = getPayload(x)
+    check_response(o, failed_case=False)
+
+    files = get_files_in_local_dir('', local_pools_dir)
+    assert len(files) == 0, 'Wipe_all_pools failed: ' + \
+        o['msg'] + 'Files ' + str(files)
+
+
+def test_new_user_read_write(new_user_read_write):
+    """
+    GIVEN a User model
+    WHEN a new User is created
+    THEN check the username, hashed_password, authenticated, and role fields are defined correctly
+    https://www.patricksoftwareblog.com/testing-a-flask-application-using-pytest/
+    """
+    new_user = new_user_read_write
+    assert new_user.username == 'rww'
+    assert new_user.hashed_password != 'FlaskIsAwesome'
+    assert not new_user.authenticated
+    assert new_user.role == 'read_write'
+    logger.debug('Done.')
+
+
+def test_new_user_read_only(new_user_read_only):
+    """
+    GIVEN a User model
+    WHEN a new User is created
+    THEN check the username, hashed_password, authenticated, and role fields are defined correctly
+    """
+    new_user = new_user_read_only
+    assert new_user.username == 'aas'
+    assert new_user.hashed_password != 'FlaskIsAwesome'
+    assert not new_user.authenticated
+    assert new_user.role == 'read_only'
+    logger.debug('Done.')
+
+
+def test_unauthorizedread_write(server, new_user_read_only, client):
+    aburl, headers = server
+    # generate a unauthorized user header
+    headers = auth_headers('k', 'hu8')
+    x = client.get(aburl+'/pools', headers=headers)
+    assert x.status_code == 200
+    # with pytest.raises(URLError):
+    o = getPayload(x)
+    check_response(o)
+    pools = o['result']
+    assert isinstance(pools, list)
+    logger.debug('Done.')
+
+
+def test_authorizedread_write(server, new_user_read_write, client):
+    aburl, headers = server
+    headers = auth_headers('k', 'hu8')
+    x = client.get(aburl+'/pools', headers=headers)
+    assert x.status_code == 200
+    # with pytest.raises(URLError):
+    o = getPayload(x)
+    check_response(o)
+    pools = o['result']
+    assert isinstance(pools, list)
+
+
+def test_root(server, client):
+    aburl, headers = server
+    url = aburl + '/'+'pools'
+    x = client.get(url)
+    o = getPayload(x)
+    check_response(o)
+    c_pools = o['result']
+    # /
+    url = aburl + '/'
+    x = client.get(url)
+    o = getPayload(x)
+    check_response(o)
+    c = o['result']
+    assert len(c) == 0
+    #
+    url = aburl
+    x = client.get(url)
+    o = getPayload(x)
+    if check_response(o, excluded=['Redirecting']):
+        c = o['result']
+        assert c_pools == c
 
 
 def clear_server_local_pools_dir(poolid, local_pools_dir):
@@ -143,18 +320,7 @@ def clear_server_local_pools_dir(poolid, local_pools_dir):
         # x = requests.post(url, auth=HTTPBasicAuth(*userpass), data=data)
 
 
-def get_dirs(local_pools_dir):
-    """ returns a list of directories in server pool dir. """
-
-    path = local_pools_dir
-    if os.path.exists(path):
-        files = os.listdir(path)
-    else:
-        files = []
-    return files
-
-
-def get_files(poolid, local_pools_dir):
+def get_files_in_local_dir(poolid, local_pools_dir):
     """ returns a list of files in the given poolid in server pool dir. """
 
     ppath = os.path.join(local_pools_dir, poolid)
@@ -165,26 +331,16 @@ def get_files(poolid, local_pools_dir):
     return files
 
 
-def test_clear_server(local_pools_dir):
-    clrpool = 'test_clear'
-    ppath = os.path.join(local_pools_dir, clrpool)
-    if not os.path.exists(ppath):
-        os.makedirs(ppath)
-    assert os.path.exists(ppath)
-    with open(ppath+'/foo', 'w') as f:
-        f.write('k')
-    clear_server_local_pools_dir(clrpool, local_pools_dir)
-    assert not os.path.exists(ppath)
+def empty_pool(post_poolid, aburl, auth, clnt):
+    path = post_poolid + '/api/removeAll'
+    url = aburl + '/' + path
+    x = clnt.get(url, auth=HTTPBasicAuth(*auth))
+    o = getPayload(x)
+    # ignore "FAILED" so non-exisiting target will not cause a failed case.
+    check_response(o, failed_case=None)
 
 
-def empty_pool_on_server(post_poolid, aburl, auth):
-    url = aburl + '/' + post_poolid + '/api/removeAll'
-    x = requests.get(url, auth=HTTPBasicAuth(*auth))
-    o = deserialize(x.text)
-    check_response(o)
-
-
-def populate_server(poolid, aburl, auth):
+def populate_pool(poolid, aburl, auth, clnt):
     creators = ['Todds', 'Cassandra', 'Jane', 'Owen', 'Julian', 'Maurice']
     instruments = ['fatman', 'herscherl', 'NASA', 'CNSC', 'SVOM']
 
@@ -195,33 +351,35 @@ def populate_server(poolid, aburl, auth):
         x.creator = i
         data = serialize(x)
         url = aburl + '/' + poolid + '/' + prodt + '/' + str(index)
-        # print(len(data))
-
-        x = requests.post(url, auth=HTTPBasicAuth(*auth), data=data)
-        o = deserialize(x.text)
+        x = clnt.post(url, auth=HTTPBasicAuth(*auth), data=data)
+        print(len(data))
+        o = getPayload(x)
         check_response(o)
         urns.append(o['result'])
+
     return creators, instruments, urns
 
 
-def test_CRUD_product(local_pools_dir, setup, userpass):
+def test_CRUD_product(local_pools_dir, server, userpass, client):
     ''' test saving, read, delete products API, products will be saved at /data/pool_id
     '''
 
     logger.info('save products')
-    aburl, headers = setup
+    aburl, headers = server
     post_poolid = test_poolid
+    auth = HTTPBasicAuth(*userpass)
     # register
-    pool = PoolManager.getPool(test_poolid, aburl + '/'+test_poolid)
-    empty_pool_on_server(post_poolid, aburl, userpass)
+    pool = make_pools(test_poolid, aburl, client, auth, n=1)
+    empty_pool(post_poolid, aburl, userpass, client)
 
-    files = [f for f in get_files(
+    files = [f for f in get_files_in_local_dir(
         post_poolid, local_pools_dir) if f[-1].isnumeric()]
     origin_prod = len(files)
 
-    creators, instruments, urns = populate_server(post_poolid, aburl, userpass)
+    creators, instruments, urns = populate_pool(
+        post_poolid, aburl, userpass, client)
 
-    files1 = [f for f in get_files(
+    files1 = [f for f in get_files_in_local_dir(
         post_poolid, local_pools_dir) if f[-1].isnumeric()]
     num_prod = len(files1)
     assert num_prod == len(creators) + origin_prod, 'Products number not match'
@@ -236,8 +394,8 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
     u = random.choice(urns)
     # remove the leading 'urn:'
     url = aburl + '/' + u[4:].replace(':', '/')
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     assert o['result'].creator == creators[urns.index(u)], 'Creator not match'
 
@@ -247,11 +405,11 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
     logger.info('read hk')
     hkpath = '/hk'
     url = aburl + '/' + post_poolid + hkpath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o1 = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o1 = getPayload(x)
     url2 = aburl + '/' + post_poolid + '/api/readHK'
-    x2 = requests.get(url2, auth=HTTPBasicAuth(*userpass))
-    o2 = deserialize(x2.text)
+    x2 = client.get(url2, auth=auth)
+    o2 = getPayload(x2)
     for o in [o1, o2]:
         check_response(o)
         assert o['result']['classes'] is not None, 'Classes jsn read failed'
@@ -269,8 +427,8 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
     logger.info('read classes')
     hkpath = '/hk/classes'
     url = aburl + '/' + post_poolid + hkpath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     assert o['result'][prodt]['sn'][-l:] == inds
     assert o['result'][prodt]['currentSN'] == inds[-1]
@@ -279,24 +437,24 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
     num = len(o['result'][prodt]['sn'])
     apipath = '/api/getCount/' + prodt + ':str'
     url = aburl + '/' + post_poolid + apipath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     assert o['result'] == num
 
     logger.info('read tags')
     hkpath = '/hk/tags'
     url = aburl + '/' + post_poolid + hkpath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     assert len(o['result']) == 0
 
     logger.info('read urns')
     hkpath = '/hk/urns'
     url = aburl + '/' + post_poolid + hkpath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
 
     assert set(o['result'].keys()) == set(urns)
@@ -304,19 +462,19 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
     # ========
     logger.info('delete a product')
 
-    files = [f for f in get_files(
+    files = [f for f in get_files_in_local_dir(
         post_poolid, local_pools_dir) if f[-1].isnumeric()]
     origin_prod = len(files)
 
     index = files[-1].rsplit('_', 1)[1]
     url = aburl + '/' + post_poolid + '/fdi.dataset.product.Product/' + index
 
-    x = requests.delete(url, auth=HTTPBasicAuth(*userpass))
+    x = client.delete(url, auth=auth)
 
-    o = deserialize(x.text)
+    o = getPayload(x)
     check_response(o)
 
-    files1 = [f for f in get_files(
+    files1 = [f for f in get_files_in_local_dir(
         post_poolid, local_pools_dir) if f[-1].isnumeric()]
     num_prod = len(files1)
     assert num_prod + 1 == origin_prod, 'Products number not match'
@@ -328,43 +486,45 @@ def test_CRUD_product(local_pools_dir, setup, userpass):
 
     # ========
     logger.info('wipe a pool')
-    files = get_files(post_poolid, local_pools_dir)
+    files = get_files_in_local_dir(post_poolid, local_pools_dir)
     assert len(files) != 0, 'Pool is already empty: ' + post_poolid
 
     # wipe the pool on the server
     url = aburl + '/' + post_poolid + '/api/removeAll'
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
 
-    files = get_files(post_poolid, local_pools_dir)
+    files = get_files_in_local_dir(post_poolid, local_pools_dir)
     assert len(files) == 0, 'Wipe pool failed: ' + o['msg']
 
     url = aburl + '/' + post_poolid + '/api/isEmpty'
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     assert o['result'] == True
 
+    # ========
     logger.info('unregister a pool on the server')
     url = aburl + '/' + post_poolid
-    x = requests.delete(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
-    check_response(o)
+    x = client.delete(url, auth=auth)
+    o = getPayload(x)
+    check_response(o, failed_case=True)
 
     # this should fail as pool is unregistered on the server
     url = aburl + '/' + post_poolid + '/api/isEmpty'
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o, failed_case=True)
 
 
-def test_product_path(setup, userpass):
+def test_product_path(server, userpass, client):
 
-    aburl, headers = setup
+    aburl, headers = server
     auth = HTTPBasicAuth(*userpass)
-    pool = PoolManager.getPool(test_poolid, aburl + '/'+test_poolid)
-    # empty_pool_on_server(post_poolid,aburl,userpass)
+    # empty_pool(post_poolid,aburl,userpass)
+    pstore = ProductStorage(test_poolid, aburl + '/'+test_poolid)
+    pool = PoolManager.getPool(test_poolid)
 
     url0 = aburl + '/' + test_poolid + '/'
     # write sample product to the pool
@@ -373,57 +533,57 @@ def test_product_path(setup, userpass):
     data = serialize(p)
     # print(len(data))
     url1 = url0+prodt + '/0'
-    x = requests.post(url1, auth=auth, data=data)
-    o = deserialize(x.text)
+    x = client.post(url1, auth=auth, data=data)
+    o = getPayload(x)
     check_response(o)
     urn = o['result']
 
     # API
     pcls = urn.split(':')[2].replace(':', '/')
     urlapi = url0 + pcls
-    # 'http://0.0.0.0:5000/v0.7/test/fdi.dataset.product.Product'
-    x = requests.get(urlapi, auth=auth)
-    o = deserialize(x.text)
+    # 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/fdi.dataset.product.Product'
+    x = client.get(urlapi, auth=auth)
+    o = getPayload(x)
     check_response(o)
     c = o['result']
     # pprint(c)
     assert 'metadata' in c
 
     # test product paths
-    segs = ["results", "energy_table", "Energy", "data"]
+    segs = ["results", "Time_Energy_Pos", "Energy", "data"]
     pth = '/'.join(segs)
     # make url w/  urn1
-    # 'http://0.0.0.0:5000/v0.7/test/urn+test+fdi.dataset.product.Product+0/results/energy_table/Energy/data'
+    #
     url2 = url0 + urn.replace(':', '+') + '/' + pth
-    x = requests.get(url2, auth=auth)
-    o = deserialize(x.text)
+    x = client.get(url2, auth=auth)
+    o = getPayload(x)
     check_response(o)
     c = o['result']
-    assert c == p['results']['energy_table']['Energy'].data
+    assert c == p['results']['Time_Energy_Pos']['Energy'].data
     # make w/ prodtype
     # fdi.dataset.product.Product/0
     pt = urn.split(':', 2)[2].replace(':', '/')
 
     urlp = url0 + pt
-    # http://0.0.0.0:5000/v0.7/test/fdi.dataset.product.Product/0/results/energy_table/Energy/data
+    # http://0.0.0.0:5000/v0.7/fdi_serv.test_httppool/fdi.dataset.product.Product/0/results/Time_Energy_Pos/Energy/data
     url3 = urlp + '/' + pth
-    x = requests.get(url3, auth=auth)
-    o = deserialize(x.text)
+    x = client.get(url3, auth=auth)
+    o = getPayload(x)
     check_response(o)
     c2 = o['result']
-    assert c == p['results']['energy_table']['Energy'].data
+    assert c == p['results']['Time_Energy_Pos']['Energy'].data
 
     for pth in [
             "description",
-            "meta/extra/unit",
-            "meta/extra/value",
-            "meta/extra/isValid",
-            "arraydset 1/data",
-            "results/calibration_arraydset/unit",
+            "meta/speed/unit",
+            "meta/speed/value",
+            "meta/speed/isValid",
+            "Temperature/data",
+            "results/calibration/unit",
     ]:
         url = urlp + '/' + pth
-        x = requests.get(url, auth=auth)
-        o = deserialize(x.text)
+        x = client.get(url, auth=auth)
+        o = getPayload(x)
         check_response(o)
         c = o['result']
         f, s = fetch(pth, p)
@@ -431,56 +591,33 @@ def test_product_path(setup, userpass):
     # members
 
     url = url0 + pt + '/'
-    x = requests.get(url, auth=auth)
-    o = deserialize(x.text)
+    x = client.get(url, auth=auth)
+    o = getPayload(x)
     check_response(o)
     c = o['result']
     assert 'description' in c
 
     # string
 
-    # 'http://0.0.0.0:5000/v0.7/test/string/fdi.dataset.product.Product/0'
+    # 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/string/fdi.dataset.product.Product/0'
     url = url0 + pt + '/$string'
-    x = requests.get(url, auth=auth)
+    x = client.get(url, auth=auth)
     assert x.headers['Content-Type'] == 'text/plain'
-    c = x.text
+    c = getPayload(x)
     # print(c)
     assert 'UNKNOWN' in c
 
 
-def test_get_pools(local_pools_dir, setup):
+def test_get_pools(local_pools_dir, server, client):
 
-    aburl, headers = setup
+    aburl, headers = server
     url = aburl + '/'+'pools'
-    x = requests.get(url)
-    o = deserialize(x.text)
+    x = client.get(url)
+    o = getPayload(x)
     check_response(o)
     c = o['result']
     assert len(c)
-    assert set(c) == set(get_dirs(local_pools_dir))
-
-
-def test_root(setup):
-    aburl, headers = setup
-    url = aburl + '/'+'pools'
-    x = requests.get(url)
-    o = deserialize(x.text)
-    check_response(o)
-    c_pools = o['result']
-    # /
-    url = aburl + '/'
-    x = requests.get(url)
-    o = deserialize(x.text)
-    check_response(o)
-    c = o['result']
-    assert c_pools == c
-    # /
-    url = aburl
-    x = requests.get(url)
-    o = deserialize(x.text)
-    check_response(o)
-    c = o['result']
-    assert c_pools == c
+    assert set(c) == set(get_files_in_local_dir('', local_pools_dir))
 
 
 async def lock_pool(poolid, sec, local_pools_dir):
@@ -493,14 +630,14 @@ async def lock_pool(poolid, sec, local_pools_dir):
     logger.debug(lock)
     with filelock.FileLock(lock):
         await asyncio.sleep(sec)
-    fakeres = '{"result": "FAILED", "msg": "This is a fake responses", "timestamp": ' + \
+    fakeres = '{"code":400, "result": "FAILED", "msg": "This is a fake responses", "time": ' + \
         str(time.time()) + '}'
     return deserialize(fakeres)
 
 
-async def read_product(poolid, setup, userpass):
+async def read_product(poolid, server, userpass):
 
-    aburl, headers = setup
+    aburl, headers = server
     # trying to read
     if 1:
         prodpath = '/'+prodt+'/0'
@@ -517,22 +654,22 @@ async def read_product(poolid, setup, userpass):
     return o
 
 
-def test_lock_file(setup, userpass, local_pools_dir):
+def test_lock_file(server, userpass, local_pools_dir, client):
     ''' Test if a pool is locked, others can not manipulate this pool anymore before it's released
     '''
     logger.info('Test read a locked file, it will return FAILED')
-    aburl, headers = setup
+    aburl, headers = server
     poolid = test_poolid
     # init server
-    populate_server(poolid, aburl, userpass)
-    #hkpath = '/hk/classes'
-    #url = aburl + '/' + poolid + hkpath
-    #x = requests.get(url, auth=HTTPBasicAuth(*userpass))
+    populate_pool(poolid, aburl, userpass, client)
+    # hkpath = '/hk/classes'
+    # url = aburl + '/' + poolid + hkpath
+    # x = client.get(url, auth=HTTPBasicAuth(*userpass))
 
     try:
         loop = asyncio.get_event_loop()
         tasks = [asyncio.ensure_future(
-            lock_pool(poolid, 2, local_pools_dir)), asyncio.ensure_future(read_product(poolid, setup, userpass))]
+            lock_pool(poolid, 2, local_pools_dir)), asyncio.ensure_future(read_product(poolid, server, userpass))]
         taskres = loop.run_until_complete(asyncio.wait(tasks))
         loop.close()
     except Exception as e:
@@ -547,20 +684,20 @@ def test_lock_file(setup, userpass, local_pools_dir):
     check_response(r1, True)
 
 
-def test_read_non_exists_pool(setup, userpass):
+def test_read_non_exists_pool(server, userpass, client):
     ''' Test read a pool which doesnot exist, returns FAILED
     '''
     logger.info('Test query a pool non exist.')
-    aburl, headers = setup
+    aburl, headers = server
     wrong_poolid = 'abc'
     prodpath = '/' + prodt + '/0'
     url = aburl + '/' + wrong_poolid + prodpath
-    x = requests.get(url, auth=HTTPBasicAuth(*userpass))
-    o = deserialize(x.text)
+    x = client.get(url, auth=HTTPBasicAuth(*userpass))
+    o = getPayload(x)
     check_response(o, True)
 
 
-def XXXtest_subclasses_pool(userpass):
+def XXXtest_subclasses_pool(userpass, client):
     logger.info('Test create a pool which has subclass')
     poolid_1 = 'subclasses/a'
     poolid_2 = 'subclasses/b'
@@ -570,12 +707,12 @@ def XXXtest_subclasses_pool(userpass):
     x = Product(description="product example with several datasets",
                 instrument="Crystal-Ball", modelName="Mk II")
     data = serialize(x)
-    res1 = requests.post(url1, auth=HTTPBasicAuth(
+    res1 = client.post(url1, auth=HTTPBasicAuth(
         *userpass), data=data)
-    res2 = requests.post(url2, auth=HTTPBasicAuth(
+    res2 = client.post(url2, auth=HTTPBasicAuth(
         *userpass), data=data)
-    o1 = deserialize(res1.text)
-    o2 = deserialize(res2.text)
+    o1 = getPayload(res1)
+    o2 = getPayload(res2)
     check_response(o1)
     check_response(o2)
 
@@ -583,11 +720,11 @@ def XXXtest_subclasses_pool(userpass):
     url1 = aburl + '/' + poolid_1
     url2 = aburl + '/' + poolid_2
 
-    res1 = requests.delete(url1,  auth=HTTPBasicAuth(*userpass))
-    res2 = requests.delete(url2,  auth=HTTPBasicAuth(*userpass))
-    o1 = deserialize(res1.text)
+    res1 = client.delete(url1,  auth=HTTPBasicAuth(*userpass))
+    res2 = client.delete(url2,  auth=HTTPBasicAuth(*userpass))
+    o1 = getPayload(res1)
     check_response(o1)
-    o2 = deserialize(res2.text)
+    o2 = getPayload(res2)
     check_response(o2)
 
 
